@@ -1,7 +1,9 @@
 """Tests for the ``pip hash`` command"""
+from tests.lib import PipTestEnvironment
+from tests.lib.path import Path
 
 
-def test_basic_hash(script, tmpdir):
+def test_basic_hash(script: PipTestEnvironment, tmpdir: Path) -> None:
     """Run 'pip hash' through its default behavior."""
     expected = (
         "--hash=sha256:2cf24dba5fb0a30e26e83b2ac5b9e29e1b161e5c1fa7425"
@@ -11,7 +13,7 @@ def test_basic_hash(script, tmpdir):
     assert expected in str(result)
 
 
-def test_good_algo_option(script, tmpdir):
+def test_good_algo_option(script: PipTestEnvironment, tmpdir: Path) -> None:
     """Make sure the -a option works."""
     expected = (
         "--hash=sha512:9b71d224bd62f3785d96d46ad3ea3d73319bfbc2890caad"
@@ -22,7 +24,7 @@ def test_good_algo_option(script, tmpdir):
     assert expected in str(result)
 
 
-def test_bad_algo_option(script, tmpdir):
+def test_bad_algo_option(script: PipTestEnvironment, tmpdir: Path) -> None:
     """Make sure the -a option raises an error when given a bad operand."""
     result = script.pip(
         "hash", "-a", "invalidname", _hello_file(tmpdir), expect_error=True
@@ -30,7 +32,7 @@ def test_bad_algo_option(script, tmpdir):
     assert "invalid choice: 'invalidname'" in str(result)
 
 
-def _hello_file(tmpdir):
+def _hello_file(tmpdir: Path) -> Path:
     """Return a temp file to hash containing "hello"."""
     file = tmpdir / "hashable"
     file.write_text("hello")
